use std::io::Read;

fn main() {
    let f = if std::env::args_os().len() < 2 {
        let mut buf = vec![];
        std::io::stdin().lock().read_to_end(&mut buf).unwrap();
        buf
    } else if std::env::args_os().len() == 2 {
        // TODO collect all files
        // TODO decode FLAC, WAV
        std::fs::read(std::env::args_os().skip(1).next().unwrap()).unwrap()
    } else {
        panic!("expected 0 or 1 files");
    };

    assert_eq!(f.len() / 4 * 4, f.len());

    let first_nonzero_sample = f
        .chunks(4)
        .enumerate()
        .find(|(_i, c)| c != &[0, 0, 0, 0])
        .unwrap()
        .0;
    let last_nonzero_sample = f
        .chunks(4)
        .enumerate()
        .rev()
        .find(|(_i, c)| c != &[0, 0, 0, 0])
        .unwrap()
        .0;
    let uh_bytes = &f[first_nonzero_sample * 4..(last_nonzero_sample + 1) * 4];
    let uh_hash = sha1_smol::Sha1::from(uh_bytes).hexdigest();
    println!("Universal Hash (SHA-1): {uh_hash}");
    const SCRAM_OFFSET: isize = 44100 * (60 * 10 + 2);
    println!(
        "non-zero data start: {first_nonzero_sample:+} ({:+} assuming .scram)",
        isize::try_from(first_nonzero_sample).unwrap() - SCRAM_OFFSET
    );
}
